@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gcu/application.cc 
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,20 +26,20 @@
 #include "application.h"
 #include <gconf/gconf-client.h>
 #include <sys/stat.h>
-#include <cstdlib>
 
 using namespace gcu;
 
-Application::Application (string name, string datadir)
+Application::Application (string name, string datadir, char const *help_name, char const *icon_name)
 {
 	Name = name;
 	string lang = getenv ("LANG");
-	HelpFilename = datadir + string ("/gnome/help/") + Name + string ("/") + lang + string ("/") + Name + ".xml";
+	string HelpName = help_name? help_name: Name;
+	HelpFilename = datadir + string ("/gnome/help/") + HelpName + string ("/") + lang + string ("/") + HelpName + ".xml";
 	struct stat buf;
 	gint err;
 	err = stat (HelpFilename.c_str (), &buf);
 	if (err)
-		HelpFilename = datadir + string ("/gnome/help/") + Name + string ("/C/") + Name + ".xml";
+		HelpFilename = datadir + string ("/gnome/help/") + HelpName + string ("/C/") + HelpName + ".xml";
 	GConfClient* cli = gconf_client_get_default ();
 	if (cli) {
 		const char *value;
@@ -48,11 +48,31 @@ Application::Application (string name, string datadir)
 			value = gconf_value_get_string (gconf_entry_get_value (entry));
 			if (value) HelpBrowser = value;
 		}
+		entry = gconf_client_get_entry (cli, "/desktop/gnome/applications/browser/exec", NULL, true, NULL);
+		if (entry) {
+			value = gconf_value_get_string (gconf_entry_get_value (entry));
+			if (value) WebBrowser = value;
+		}
+		entry = gconf_client_get_entry (cli, "/desktop/gnome/url-handlers/mailto/command", NULL, true, NULL);
+		if (entry) {
+			value = gconf_value_get_string (gconf_entry_get_value (entry));
+			if (value) {
+				MailAgent = value;
+				int i = MailAgent.find (" %s");
+				if (i > 0)
+					MailAgent.erase (i, MailAgent.size ());
+			}
+		}
 	}
+	CurDir = g_get_current_dir ();
+	g_set_application_name (name.c_str ());
+	gtk_window_set_default_icon_name (icon_name? icon_name: (help_name? help_name: Name.c_str ()));
 }
 
 Application::~Application ()
 {
+	if (CurDir)
+		g_free (CurDir);
 }
 
 void Application::OnHelp (string tag)
@@ -78,3 +98,31 @@ bool Application::HasHelp ()
 	err = stat (HelpFilename.c_str (), &buf);
 	return (err)? false: true;	
 }
+
+void Application::SetCurDir (char const* dir)
+{
+	if (CurDir)
+		g_free (CurDir);
+	CurDir = g_strdup (dir);
+}
+
+void Application::OnMail (char *MailAddress)
+{
+	if (!MailAgent.size ())
+		return;
+	char *argv[3] = {NULL, MailAddress, NULL};
+	argv[0] = (char*) MailAgent.c_str();
+	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
+		NULL, NULL, NULL, NULL);
+}
+
+void Application::ShowURI (string& uri)
+{
+	if (!WebBrowser.size ())
+		return;
+	char *argv[3] = {NULL, NULL, NULL};
+	argv[0] = (char*) WebBrowser.c_str();
+	argv[1] = (char*) uri.c_str ();
+	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
+		NULL, NULL, NULL, NULL);
+}
